@@ -25,20 +25,7 @@
 #include <string>
 #include <sstream>
 
-
-#ifdef PBORI_HAVE_TR1_UNORDERED_MAP
-#  include <tr1/unordered_map>
-#else 
-#  ifdef PBORI_HAVE_UNORDERED_MAP
-#    include <unordered_map>
-#  else
-#    ifdef PBORI_HAVE_HASH_MAP
-#      include <ext/hash_map>
-#    else
-#     include <map>
-#    endif
-#  endif
-#endif
+#include <unordered_map>
 
 BEGIN_NAMESPACE_PBORI
 
@@ -629,20 +616,7 @@ class generate_index_map {
   typedef typename Type::idx_type idx_type;
 public:
   /// Type for index maps
-
-#ifdef PBORI_HAVE_TR1_UNORDERED_MAP
-  typedef std::tr1::unordered_map<Type, idx_type, hashes<Type> > type;
-#else
-#  ifdef PBORI_HAVE_UNORDERED_MAP
-     typedef std::unordered_map<Type, idx_type, hashes<Type> > type;
-#  else
-#    ifdef PBORI_HAVE_HASH_MAP
-       typedef __gnu_cxx::hash_map<Type, idx_type, hashes<Type> > type;
-#    else
-       typedef std::map<Type, idx_type, Comparator> type;
-#    endif
-#  endif
-#endif
+  typedef std::unordered_map<Type, idx_type, hashes<Type> > type;
 };
 
 /** @class sizes_less
@@ -750,67 +724,6 @@ public:
 
 };
 
-template <template<class> class BindType, class BinaryFunction, 
-          class ValueType, class ConstantOp>
-class constant_binder_base :
-  public BindType<BinaryFunction>{
-public:
-  typedef BinaryFunction bin_op; 
-  typedef ConstantOp const_type;
-  typedef BindType<bin_op> base;
-
-  typedef ValueType value_type;
-
-  constant_binder_base(const bin_op& op = bin_op()): base(op, const_type()()) {}
-};
-
-template <class BinaryFunction, class ConstantOp>
-class constant_binder2nd :
-  public constant_binder_base<std::binder2nd, BinaryFunction,
-                              typename BinaryFunction::second_argument_type,
-                              ConstantOp> {
-};
-
-
-template <class BinaryFunction, class ConstantOp>
-class constant_binder1st :
-  public constant_binder_base<std::binder1st, BinaryFunction,
-                              typename BinaryFunction::first_argument_type,
-                              ConstantOp> {
-};
-
-template <template<class> class BindType,
-          class BinaryFunction, class ValueType>
-class default_binder_base :
-  public BindType<BinaryFunction>{
-public:
-  typedef BinaryFunction bin_op; 
-  typedef BindType<bin_op> base;
-
-  typedef ValueType value_type;
-
-  default_binder_base(const value_type&  val): base(bin_op(), val) {}
-};
-
-template <class BinaryFunction>
-class default_binder2nd :
-  public default_binder_base<std::binder2nd, BinaryFunction,
-                              typename BinaryFunction::second_argument_type> {
-public:
-  typedef default_binder_base<std::binder2nd, BinaryFunction,
-                              typename BinaryFunction::second_argument_type>
-  base;
-
-  default_binder2nd(const typename base::value_type&  val): base(val) {}
-};
-
-
-template <class BinaryFunction>
-class default_binder1st :
-  public default_binder_base<std::binder1st, BinaryFunction,
-                              typename BinaryFunction::first_argument_type> {
-};
-
 // /** @class property_owner
 //  *  @brief defines generic base for properties
 //  **/
